@@ -33,9 +33,7 @@ def get_fields_and_nested_fields(cls: T.Type[BaseModelType]) -> T.List[str]:
 
 
 class Resolver(BaseModel, T.Generic[NodeType]):
-    # node: T.ClassVar[T.Type[NodeType]]
-    # node: T.ClassVar[T.Type[Node]]
-    node: T.ClassVar[T.Any]
+    node: T.ClassVar[T.Type[NodeType]]
 
     query_params: QueryParamsType
     edges: EdgesType
